package com.sf.web.dms.api.control;

package ..deTemp.1731091416992;

import com.smartframework.core.annotation.SmartNoSecurityFilter;
import com.smartframework.core.dao.BasicJdbcDao;
import com.smartframework.core.dao.JdbcDao;
import com.smartframework.core.dao.page.PagingBean;
import com.smartframework.core.smart.SmartView;
import com.smartframework.web.core.Constants;
import com.smartframework.web.core.queryfilter.QueryFilter;
import com.smartframework.web.core.util.ParameterUtils;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.springframework.util.FileCopyUtils;

public class RestControl {
  private JdbcDao jdbcDao;
  
  static final String orgQuerySql = "select id,description as org_name,rdf_id from con_division where description in('无锡','江苏直属','常州')";
  
  static final String modelFileFolder = "/home/smart/smartsys/modelfile/receive";
  
  static final String rtuPointsQuerySql = "select id point_id,description point_name,scada_pnt_id from fes_%s where rtu_id=?";
  
  public JdbcDao getJdbcDao() {
    return this.jdbcDao;
  }
  
  public void setJdbcDao(JdbcDao jdbcDao) {
    this.jdbcDao = jdbcDao;
  }
  
  @SmartNoSecurityFilter
  public SmartView loadOrgAndSub(String orgCode, Integer pageIndex, Integer pageSize) {
    return SmartView.SUCCESS(this.jdbcDao.queryForList("select id,description as org_name,rdf_id from con_division where description in('无锡','江苏直属','常州')"));
  }
  
  @SmartNoSecurityFilter
  public SmartView loadFeeders(String orgRdfId, Integer pageIndex, Integer pageSize) {
    if (ParameterUtils.isEmptyOrNull(pageIndex) || pageIndex.intValue() < 0)
      pageIndex = Integer.valueOf(0); 
    if (ParameterUtils.isNotValidateId(pageSize))
      pageSize = Integer.valueOf(30); 
    QueryFilter filter = QueryFilter.NEW("select a.id feeder_id,a.rdf_id feeder_rdf_id,a.graph_name feeder_name from con_feeder a left join con_station b on a.container_id = b.id");
    filter.left("con_division", "c").on("b.container_id", "c.id").where().addNumberFieldEqualCondition("c.rdf_id", orgRdfId);
    filter.setPageInfo(pageSize, pageIndex);
    PagingBean p = filter.queryForPaging((BasicJdbcDao)this.jdbcDao);
    for (Map<String, Object> m : (Iterable<Map<String, Object>>)p.getData()) {
      File f = new File(Constants.getString("dms.modelmng.feeder.xml.location", "/home/smart/smartsys/modelfile/receive") + File.separator + String.valueOf(m.get("feederName")) + ".xml");
      if (f.exists()) {
        m.put("lastModify", Long.valueOf(f.lastModified()));
        continue;
      } 
      m.put("lastModify", Integer.valueOf(0));
    } 
    return SmartView.PAGEDATA(p);
  }
  
  @SmartNoSecurityFilter
  public SmartView loadFeederModel(Long feederId) {
    if (ParameterUtils.isValidateId(feederId))
      return SmartView.ERROR("必须指定馈线ID"); 
    QueryFilter filter = QueryFilter.NEW("select a.id feeder_id,a.rdf_id feeder_rdf_id,a.graph_name feeder_name,b.rdf_id station_rdf_id,b.description station_name,c.rdf_id org_rdf_id,c.description org_name from con_feeder a left join con_station b on a.container_id = b.id");
    filter.left("con_division", "c").on("b.container_id", "c.id").where().addNumberFieldEqualCondition("a.id", feederId);
    List<Map<String, Object>> list = filter.queryForList((BasicJdbcDao)this.jdbcDao);
    if (ParameterUtils.isEmptyOrNull(list))
      return SmartView.ERROR("ID为:" + feederId + " 单线图在数据库中没有记录."); 
    String feederName = String.valueOf(((Map)list.get(0)).get("feederName"));
    String xmlFileLocation = Constants.getString("dms.modelmng.feeder.xml.location", "/home/smart/smartsys/modelfile/receive") + File.separator + feederName + ".xml";
    Map<String, Object> result = new HashMap<>();
    result.putAll(list.get(0));
    try {
      String content = FileCopyUtils.copyToString(new InputStreamReader(new FileInputStream(xmlFileLocation), Constants.UTF8));
      result.put("content", content);
    } catch (Exception e) {
      return SmartView.ERROR("读取文件:" + xmlFileLocation + " 时发生异常:" + e.getMessage());
    } 
    return SmartView.SUCCESS(result);
  }
  
  @SmartNoSecurityFilter
  public SmartView loadChans(Long feederId, Integer deepSearch) {
    if (ParameterUtils.isEmptyOrNull(feederId))
      return SmartView.ERROR("必须指定馈线ID"); 
    List<Map<String, Object>> feedersChanList = QueryFilter.NEW("select id,description chan_name,1 feeder_rtu from fes_chan").where().addNumberFieldEqualCondition("container_id", feederId).queryForList((BasicJdbcDao)this.jdbcDao);
    if (ParameterUtils.isValidateId(deepSearch)) {
      List<Map<String, Object>> list2 = QueryFilter.NEW("select a.id,b.description chan_name,0 feeder_rtu from fes_chan a left join con_compositeswitch b on a.container_id=b.id").where().addStringFieldEqualCondition("a.container_tablename", "con_compositeswitch").addNumberFieldEqualCondition("b.container_id", feederId).queryForList((BasicJdbcDao)this.jdbcDao);
      if (!list2.isEmpty())
        feedersChanList.addAll(list2); 
    } 
    return SmartView.SUCCESS(feedersChanList);
  }
  
  @SmartNoSecurityFilter
  public SmartView loadFaultIndicators(Long feederId, Integer feederRtu, Integer pageIndex, Integer pageSize) {
    if (ParameterUtils.isEmptyOrNull(pageIndex) || pageIndex.intValue() < 0)
      pageIndex = Integer.valueOf(0); 
    if (ParameterUtils.isNotValidateId(pageSize) && pageSize.intValue() != -1)
      pageSize = Integer.valueOf(30); 
    QueryFilter filter = QueryFilter.NEW("select a.id rtu_id,a.description rtu_name,a.sour1 chan_id,b.rdf_id rtu_rdf_id from fes_rtu a left join obj_dev b on a.dev_id = b.id ");
    filter.setPageInfo(pageSize, pageIndex);
    if (ParameterUtils.isValidateId(feederRtu)) {
      filter.where().addNumberFieldEqualCondition("a.type", Integer.valueOf(5)).addNumberFieldEqualCondition("a.container_id", feederId);
    } else {
      filter.left("con_compositeswitch", "c").on("a.container_id", "c.id");
      filter.where().addStringFieldEqualCondition("a.container_tablename", "con_compositeswitch");
      filter.addNumberFieldEqualCondition("a.type", Integer.valueOf(5)).addNumberFieldEqualCondition("c.container_id", feederId);
    } 
    PagingBean p = filter.queryForPaging((BasicJdbcDao)this.jdbcDao);
    List<Long> channelIds = new ArrayList<>();
    for (Map<String, Object> m : (Iterable<Map<String, Object>>)p.getData()) {
      if (m.get("chanId") == null)
        continue; 
      channelIds.add(Long.valueOf(Long.parseLong(String.valueOf(m.get("chanId")))));
    } 
    return SmartView.PAGEDATA(p);
  }
  
  @SmartNoSecurityFilter
  public SmartView loadRtuPoints(Long rtuId, List<String> pointTypes) {
    if (ParameterUtils.isNotValidateId(rtuId) || ParameterUtils.isEmptyOrNull(pointTypes))
      return SmartView.ERROR("请指定终端ID和要获取的点表类型"); 
    Map<String, Object> pointsMap = new HashMap<>();
    pointsMap.put("rtuId", rtuId);
    pointsMap.put("pointTypes", pointTypes);
    for (String pointType : pointTypes) {
      String sql = String.format("select id point_id,description point_name,scada_pnt_id from fes_%s where rtu_id=?", new Object[] { pointType });
      System.out.println(sql);
      pointsMap.put(pointType, this.jdbcDao.queryForList(sql, new Object[] { rtuId }));
    } 
    return SmartView.SUCCESS(pointsMap);
  }
  
  @SmartNoSecurityFilter
  public SmartView notifyFaResult(String stationId, List<String> lineId, Integer timestamp, String clientId, String scerKey) {
    if (!Constants.getString("dms.rest.client.id.yht", "dms.yht").equals(clientId) || !Constants.getString("dms.rest.client.scerkey.yht", "28842f77a8076341a669305981d31fbc").equals(scerKey))
      return SmartView.ERROR("授权验证失败"); 
    return SmartView.SUCCESS();
  }
}
